SeekableStream

Trait SeekableStream 

pub trait SeekableStream:
    AsyncRead
    + Unpin
    + Debug
    + Send
    + Sync
    + DynClone {
    // Required methods
    fn reset<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
    fn len(&self) -> Option<u64>;

    // Provided methods
    fn is_empty(&self) -> Option<bool> { ... }
    fn buffer_size(&self) -> usize { ... }
}
Enable a type implementing AsyncRead to be consumed as if it were a Stream of Bytes.

Required Methods

fn reset<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

Resets the stream position to the beginning.

fn len(&self) -> Option<u64>

Returns the total length of the stream in bytes, if known.

Notes

TransportPolicy implementations will most often want to send a content-length header when len returns Some but use transfer-encoding: chunked when len returns None.

Provided Methods

fn is_empty(&self) -> Option<bool>

Returns true if the stream is empty, if known.

fn buffer_size(&self) -> usize

Returns the size of the buffer to use when reading from the stream.