pub trait SeekableStream:
AsyncRead
+ Unpin
+ Debug
+ Send
+ Sync
+ DynClone {
// Required methods
fn reset<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn len(&self) -> Option<u64>;
// Provided methods
fn is_empty(&self) -> Option<bool> { ... }
fn buffer_size(&self) -> usize { ... }
}Expand description
Enable a type implementing AsyncRead to be consumed as if it were a Stream of Bytes.
Required Methods
Provided Methods
Sourcefn buffer_size(&self) -> usize
fn buffer_size(&self) -> usize
Returns the size of the buffer to use when reading from the stream.